@@ -4,7 +4,7 @@
 
 import numpy as np
 from numba import njit, prange
-import scipy.signal
+from scipy.signal import convolve
 import tempfile
 import math
 
@@ -37,6 +37,20 @@ def _gpu_aamp_driver_not_found(*args, **kwargs):  # pragma: no cover
     driver_not_found()
 
 
+def _gpu_mpdist_driver_not_found(*args, **kwargs):  # pragma: no cover
+    """
+    Dummy function to raise CudaSupportError driver not found error.
+    """
+    driver_not_found()
+
+
+def _gpu_aampdist_driver_not_found(*args, **kwargs):  # pragma: no cover
+    """
+    Dummy function to raise CudaSupportError driver not found error.
+    """
+    driver_not_found()
+
+
 def get_pkg_name():  # pragma: no cover
     """
     Return package name.
@@ -76,10 +90,10 @@ def z_norm(a, axis=0):
     Parameters
     ----------
     a : ndarray
-        numpy array
+        NumPy array
 
-    axis : int
-        numpy axis
+    axis : int, default 0
+        NumPy array axis
 
     Returns
     -------
@@ -96,6 +110,11 @@ def check_nan(a):  # pragma: no cover
     """
     Check if the array contains NaNs.
 
+    Parameters
+    ----------
+    a : ndarray
+        NumPy array
+
     Raises
     ------
     ValueError
@@ -112,6 +131,14 @@ def check_dtype(a, dtype=np.floating):  # pragma: no cover
     """
     Check if the array type of `a` is of type specified by `dtype` parameter.
 
+    Parameters
+    ----------
+    a : ndarray
+        NumPy array
+
+    dtype : dtype, , default np.floating
+        NumPy `dtype`
+
     Raises
     ------
     TypeError
@@ -125,7 +152,7 @@ def check_dtype(a, dtype=np.floating):  # pragma: no cover
     return True
 
 
-def transpose_dataframe(a):  # pragma: no cover
+def transpose_dataframe(df):  # pragma: no cover
     """
     Check if the input is a column-wise Pandas `DataFrame`. If `True`, return a
     transpose dataframe since stumpy assumes that each row represents data from a
@@ -136,18 +163,18 @@ def transpose_dataframe(a):  # pragma: no cover
 
     Parameters
     ----------
-    a : ndarray
-        First argument.
+    df : ndarray
+        Pandas dataframe
 
     Returns
     -------
-    output : a
+    output : df
         If a is a Pandas `DataFrame` then return `a.T`. Otherwise, return `a`
     """
-    if type(a).__name__ == "DataFrame":
-        return a.T
+    if type(df).__name__ == "DataFrame":
+        return df.T
 
-    return a
+    return df
 
 
 def are_arrays_equal(a, b):  # pragma: no cover
@@ -158,10 +185,10 @@ def are_arrays_equal(a, b):  # pragma: no cover
     Parameters
     ----------
     a : ndarray
-        First argument.
+        NumPy array
 
     b : ndarray
-        Second argument.
+        NumPy array
 
     Returns
     -------
@@ -187,9 +214,9 @@ def are_distances_too_small(a, threshold=10e-6):  # pragma: no cover
     Parameters
     ----------
     a : ndarray
-        First argument.
+        NumPy array
 
-    threshold : float
+    threshold : float, default 10e-6
         Minimum value in which to compare the matrix profile to
 
     Returns
@@ -266,11 +293,155 @@ def sliding_dot_product(Q, T):
     n = T.shape[0]
     m = Q.shape[0]
     Qr = np.flipud(Q)  # Reverse/flip Q
-    QT = convolution(Qr, T)
+    QT = convolve(Qr, T)
 
     return QT.real[m - 1 : n]
 
 
+@njit(fastmath={"nsz", "arcp", "contract", "afn", "reassoc"})
+def _welford_nanvar(a, w, a_subseq_isfinite):
+    """
+    Compute the rolling variance for a 1-D array while ignoring NaNs using a modified
+    version of Welford's algorithm but is much faster than using `np.nanstd` with stride
+    tricks.
+
+    Parameters
+    ----------
+    a : ndarray
+        The input array
+
+    w : ndarray
+        The rolling window size
+
+    a_subseq_isfinite : ndarray
+        A boolean array that describes whether each subequence of length `w` within `a`
+        is finite.
+
+    Returns
+    -------
+    all_variances : ndarray
+        Rolling window nanvar
+    """
+    all_variances = np.empty(a.shape[0] - w + 1, dtype=np.float64)
+    prev_mean = 0.0
+    prev_var = 0.0
+
+    for start_idx in range(a.shape[0] - w + 1):
+        prev_start_idx = start_idx - 1
+        stop_idx = start_idx + w  # Exclusive index value
+        last_idx = start_idx + w - 1  # Last inclusive index value
+
+        if (
+            start_idx == 0
+            or not a_subseq_isfinite[prev_start_idx]
+            or not a_subseq_isfinite[start_idx]
+        ):
+            curr_mean = np.nanmean(a[start_idx:stop_idx])
+            curr_var = np.nanvar(a[start_idx:stop_idx])
+        else:
+            curr_mean = prev_mean + (a[last_idx] - a[prev_start_idx]) / w
+            curr_var = (
+                prev_var
+                + (a[last_idx] - a[prev_start_idx])
+                * (a[last_idx] - curr_mean + a[prev_start_idx] - prev_mean)
+                / w
+            )
+
+        all_variances[start_idx] = curr_var
+
+        prev_mean = curr_mean
+        prev_var = curr_var
+
+    return all_variances
+
+
+def welford_nanvar(a, w=None):
+    """
+    Compute the rolling variance for a 1-D array while ignoring NaNs using a modified
+    version of Welford's algorithm but is much faster than using `np.nanstd` with stride
+    tricks.
+
+    This is a convenience wrapper around the `_welford_nanvar` function.
+
+    Parameters
+    ----------
+    a : ndarray
+        The input array
+
+    w : ndarray, default None
+        The rolling window size
+
+    Returns
+    -------
+    output : ndarray
+        Rolling window nanvar.
+    """
+    if w is None:
+        w = a.shape[0]
+
+    a_subseq_isfinite = rolling_isfinite(a, w)
+
+    return _welford_nanvar(a, w, a_subseq_isfinite)
+
+
+def welford_nanstd(a, w=None):
+    """
+    Compute the rolling standard deviation for a 1-D array while ignoring NaNs using
+    a modified version of Welford's algorithm but is much faster than using `np.nanstd`
+    with stride tricks.
+
+    This a convenience wrapper around `welford_nanvar`.
+
+    Parameters
+    ----------
+    a : ndarray
+        The input array
+
+    w : ndarray, default None
+        The rolling window size
+
+    Returns
+    -------
+    output : ndarray
+        Rolling window nanstd.
+    """
+    if w is None:
+        w = a.shape[0]
+
+    return np.sqrt(welford_nanvar(a, w))
+
+
+def rolling_nanstd(a, w):
+    """
+    Compute the rolling standard deviation for 1-D and 2-D arrays while ignoring NaNs
+    using a modified version of Welford's algorithm but is much faster than using
+    `np.nanstd` with stride tricks.
+
+    This a convenience wrapper around `welford_nanstd`.
+
+    This essentially replaces:
+
+        `np.nanstd(rolling_window(T[..., start:stop], m), axis=T.ndim)`
+
+    Parameters
+    ----------
+    a : ndarray
+        The input array
+
+    w : ndarray
+        The rolling window size
+
+    Returns
+    -------
+    output : ndarray
+        Rolling window nanstd.
+    """
+    axis = a.ndim - 1  # Account for rolling
+    return np.apply_along_axis(
+        lambda a_row, w: welford_nanstd(a_row, w), axis=axis, arr=a, w=w
+    )
+
+
 def compute_mean_std(T, m):
     """
     Compute the sliding mean and standard deviation for the array `T` with
@@ -334,7 +505,7 @@ def compute_mean_std(T, m):
 
                 tmp_mean = np.mean(rolling_window(T[..., start:stop], m), axis=T.ndim)
                 mean_chunks.append(tmp_mean)
-                tmp_std = np.nanstd(rolling_window(T[..., start:stop], m), axis=T.ndim)
+                tmp_std = rolling_nanstd(T[..., start:stop], m)
                 std_chunks.append(tmp_std)
 
             M_T = np.hstack(mean_chunks)
@@ -629,10 +800,10 @@ def mass(Q, T, M_T=None, Σ_T=None):
     T : ndarray
         Time series or sequence
 
-    M_T : ndarray (optional)
+    M_T : ndarray, default None
         Sliding mean of `T`
 
-    Σ_T : ndarray (optional)
+    Σ_T : ndarray, default None
         Sliding standard deviation of `T`
 
     Returns
@@ -717,7 +888,10 @@ def _mass_absolute(Q_squared, T_squared, QT):
     `See Mueen's Absolute Algorithm for Similarity Search \
     <https://www.cs.unm.edu/~mueen/MASS_absolute.m>`__
     """
-    return np.sqrt(Q_squared + T_squared - 2 * QT)
+    D = Q_squared + T_squared - 2 * QT
+    D[D < config.STUMPY_D_SQUARED_THRESHOLD] = 0.0
+
+    return np.sqrt(D)
 
 
 def mass_absolute(Q, T):
@@ -770,7 +944,7 @@ def mass_absolute(Q, T):
     if np.any(~np.isfinite(Q)):
         distance_profile[:] = np.inf
     else:
-        T_subseq_isfinite = np.all(np.isfinite(rolling_window(T, m)), axis=1)
+        T_subseq_isfinite = rolling_isfinite(T, m)
         T[~np.isfinite(T)] = 0.0
         QT = sliding_dot_product(Q, T)
         Q_squared = np.sum(Q * Q)
@@ -910,7 +1084,7 @@ def preprocess_non_normalized(T, m):
     check_dtype(T)
 
     T[np.isinf(T)] = np.nan
-    T_subseq_isfinite = np.all(np.isfinite(rolling_window(T, m)), axis=1)
+    T_subseq_isfinite = rolling_isfinite(T, m)
     T[np.isnan(T)] = 0
 
     return T, T_subseq_isfinite
@@ -987,7 +1161,7 @@ def replace_distance(D, search_val, replace_val, epsilon=0.0):
     replace_val : float
         Value to replace with
 
-    epsilon : float
+    epsilon : float, default 0.0
         Threshold below `search_val` in which to still allow for a replacement
 
     Return
@@ -1004,7 +1178,7 @@ def array_to_temp_file(a):
     Parameters
     ----------
     a : ndarray
-        An array to be written to a file
+        A NumPy array to be written to a file
 
     Returns
     -------
@@ -1067,7 +1241,7 @@ def _get_array_ranges(a, n_chunks, truncate=False):
     n_chunks : int
         Number of chunks to split the array into
 
-    truncate : bool
+    truncate : bool, default False
         If `truncate=True`, truncate the rows of `array_ranges` if there are not enough
         elements in `a` to be chunked up into `n_chunks`.  Otherwise, if
         `truncate=False`, all extra chunks will have their start and stop indices set
@@ -1099,4 +1273,36 @@ def _get_array_ranges(a, n_chunks, truncate=False):
     return array_ranges
 
 
-convolution = scipy.signal.fftconvolve  # Swap for other convolution function
+def rolling_isfinite(a, w):
+    """
+    Determine if all elements in each rolling window `isfinite`
+
+    Parameters
+    ----------
+    a : ndarray
+        The input array
+
+    w : int
+        The length of the rolling window
+
+    Return
+    ------
+    output : ndarray
+        A boolean array of length `a.shape[0] - w + 1` that records whether each
+        rolling window subsequence contain all finite values
+    """
+    if a.dtype == np.dtype("bool"):
+        a_isfinite = a.copy()
+    else:
+        a_isfinite = np.isfinite(a)
+    a_subseq_isfinite = rolling_window(a_isfinite, w)
+
+    # Process first subsequence
+    a_first_subseq = ~a_isfinite[:w]
+    if a_first_subseq.any():
+        a_isfinite[: np.flatnonzero(a_first_subseq).max()] = False
+
+    # Shift `a_isfinite` and fill forward by `w`
+    a_subseq_isfinite[~a_isfinite[w - 1 :]] = False
+
+    return a_isfinite[: a_isfinite.shape[0] - w + 1]
