@@ -38,7 +38,7 @@ def mstumped(dask_client, T, m, include=None, discords=False):
     m : int
         Window size
 
-    include : list, ndarray
+    include : list, ndarray, default None
         A list of (zero-based) indices corresponding to the dimensions in `T` that
         must be included in the constrained multidimensional motif search.
         For more information, see Section IV D in:
@@ -46,7 +46,7 @@ def mstumped(dask_client, T, m, include=None, discords=False):
         `DOI: 10.1109/ICDM.2017.66 \
         <https://www.cs.ucr.edu/~eamonn/Motif_Discovery_ICDM.pdf>`__
 
-    discords : bool
+    discords : bool, default False
         When set to `True`, this reverses the distance matrix which results in a
         multi-dimensional matrix profile that favors larger matrix profile values
         (i.e., discords) rather than smaller values (i.e., motifs). Note that indices
@@ -107,11 +107,11 @@ def mstumped(dask_client, T, m, include=None, discords=False):
         )
 
     # Scatter data to Dask cluster
-    T_A_future = dask_client.scatter(T_A, broadcast=True)
-    M_T_future = dask_client.scatter(M_T, broadcast=True)
-    Σ_T_future = dask_client.scatter(Σ_T, broadcast=True)
-    μ_Q_future = dask_client.scatter(μ_Q, broadcast=True)
-    σ_Q_future = dask_client.scatter(σ_Q, broadcast=True)
+    T_A_future = dask_client.scatter(T_A, broadcast=True, hash=False)
+    M_T_future = dask_client.scatter(M_T, broadcast=True, hash=False)
+    Σ_T_future = dask_client.scatter(Σ_T, broadcast=True, hash=False)
+    μ_Q_future = dask_client.scatter(μ_Q, broadcast=True, hash=False)
+    σ_Q_future = dask_client.scatter(σ_Q, broadcast=True, hash=False)
 
     QT_futures = []
     QT_first_futures = []
@@ -119,8 +119,8 @@ def mstumped(dask_client, T, m, include=None, discords=False):
     for i, start in enumerate(range(0, k, step)):
         QT, QT_first = _get_multi_QT(start, T_A, m)
 
-        QT_future = dask_client.scatter(QT, workers=[hosts[i]])
-        QT_first_future = dask_client.scatter(QT_first, workers=[hosts[i]])
+        QT_future = dask_client.scatter(QT, workers=[hosts[i]], hash=False)
+        QT_first_future = dask_client.scatter(QT_first, workers=[hosts[i]], hash=False)
 
         QT_futures.append(QT_future)
         QT_first_futures.append(QT_first_future)
@@ -154,4 +154,17 @@ def mstumped(dask_client, T, m, include=None, discords=False):
         stop = min(k, start + step)
         P[:, start + 1 : stop], I[:, start + 1 : stop] = results[i]
 
+    # Delete data from Dask cluster
+    dask_client.cancel(T_A_future)
+    dask_client.cancel(M_T_future)
+    dask_client.cancel(Σ_T_future)
+    dask_client.cancel(μ_Q_future)
+    dask_client.cancel(σ_Q_future)
+    for QT_future in QT_futures:
+        dask_client.cancel(QT_future)
+    for QT_first_future in QT_first_futures:
+        dask_client.cancel(QT_first_future)
+    for future in futures:
+        dask_client.cancel(future)
+
     return P.T, I.T
